import face_recognition
import os
import shutil
from tqdm import tqdm  # 导入 tqdm

# 从face文件夹中加载多张同一个人的照片，构建人脸编码列表
known_face_encodings = []
face_folder_path = "face"

# 使用 tqdm 迭代遍历
for filename in tqdm(os.listdir(face_folder_path), desc="Loading known faces"):
    if filename.endswith(('.jpg', '.jpeg', '.png', '.JPG', '.JPEG', '.PNG')):  # 确保文件是图像文件
        face_image_path = os.path.join(face_folder_path, filename)
        face_image = face_recognition.load_image_file(face_image_path)
        face_encodings = face_recognition.face_encodings(face_image)
        
        # 添加人脸编码到列表
        if len(face_encodings) > 0:
            known_face_encodings.append(face_encodings[0])
        else:
            print(f"No face detected in {filename}")

# 指定"photo"文件夹路径和"result"文件夹路径
photo_folder_path = "photo"
result_folder_path = "result"

# 创建"result"文件夹，如果不存在的话
if not os.path.exists(result_folder_path):
    os.makedirs(result_folder_path)

# 遍历"photo"文件夹中的所有图片
for filename in tqdm(os.listdir(photo_folder_path), desc="Searching for matching faces"):
    if filename.endswith(('.jpg', '.jpeg', '.png', '.JPG', '.JPEG', '.PNG')):  # 确保文件是图像文件
        current_image_path = os.path.join(photo_folder_path, filename)
        current_image = face_recognition.load_image_file(current_image_path)
        current_face_encodings = face_recognition.face_encodings(current_image)

        for current_face_encoding in current_face_encodings:
            # 使用更精确的人脸匹配方法
            matches = face_recognition.compare_faces(known_face_encodings, current_face_encoding, tolerance=0.4)
            if True in matches:
                print(f"Found a match in {filename} at {current_image_path}")
                result_image_path = os.path.join(result_folder_path, filename)
                shutil.copy(current_image_path, result_image_path)
                print(f"Matched image copied to {result_image_path}")
